==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/ConnectionConfigFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ConnectionConfigFluentImpl<A extends io.fabric8.openshift.api.model.ConnectionConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ConnectionConfigFluent<A>{
  public ConnectionConfigFluentImpl() {
  }
  public ConnectionConfigFluentImpl(io.fabric8.openshift.api.model.ConnectionConfig instance) {
    this.withCa(instance.getCa()); 
    this.withTlsClientConfig(instance.getTlsClientConfig()); 
    this.withUrl(instance.getUrl()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder ca;
  private io.fabric8.openshift.api.model.SecretNameReferenceBuilder tlsClientConfig;
  private java.lang.String url;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildCa instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConfigMapNameReference getCa() {
    return this.ca!=null?this.ca.build():null;
  }
  public io.fabric8.openshift.api.model.ConfigMapNameReference buildCa() {
    return this.ca!=null?this.ca.build():null;
  }
  public A withCa(io.fabric8.openshift.api.model.ConfigMapNameReference ca) {
    _visitables.get("ca").remove(this.ca);
    if (ca!=null){ this.ca= new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(ca); _visitables.get("ca").add(this.ca);} return (A) this;
  }
  public java.lang.Boolean hasCa() {
    return this.ca != null;
  }
  public A withNewCa(java.lang.String name) {
    return (A)withCa(new ConfigMapNameReference(name));
  }
  public io.fabric8.openshift.api.model.ConnectionConfigFluent.CaNested<A> withNewCa() {
    return new io.fabric8.openshift.api.model.ConnectionConfigFluentImpl.CaNestedImpl();
  }
  public io.fabric8.openshift.api.model.ConnectionConfigFluent.CaNested<A> withNewCaLike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
    return new io.fabric8.openshift.api.model.ConnectionConfigFluentImpl.CaNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ConnectionConfigFluent.CaNested<A> editCa() {
    return withNewCaLike(getCa());
  }
  public io.fabric8.openshift.api.model.ConnectionConfigFluent.CaNested<A> editOrNewCa() {
    return withNewCaLike(getCa() != null ? getCa(): new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.ConnectionConfigFluent.CaNested<A> editOrNewCaLike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
    return withNewCaLike(getCa() != null ? getCa(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildTlsClientConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getTlsClientConfig() {
    return this.tlsClientConfig!=null?this.tlsClientConfig.build():null;
  }
  public io.fabric8.openshift.api.model.SecretNameReference buildTlsClientConfig() {
    return this.tlsClientConfig!=null?this.tlsClientConfig.build():null;
  }
  public A withTlsClientConfig(io.fabric8.openshift.api.model.SecretNameReference tlsClientConfig) {
    _visitables.get("tlsClientConfig").remove(this.tlsClientConfig);
    if (tlsClientConfig!=null){ this.tlsClientConfig= new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(tlsClientConfig); _visitables.get("tlsClientConfig").add(this.tlsClientConfig);} return (A) this;
  }
  public java.lang.Boolean hasTlsClientConfig() {
    return this.tlsClientConfig != null;
  }
  public A withNewTlsClientConfig(java.lang.String name) {
    return (A)withTlsClientConfig(new SecretNameReference(name));
  }
  public io.fabric8.openshift.api.model.ConnectionConfigFluent.TlsClientConfigNested<A> withNewTlsClientConfig() {
    return new io.fabric8.openshift.api.model.ConnectionConfigFluentImpl.TlsClientConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.ConnectionConfigFluent.TlsClientConfigNested<A> withNewTlsClientConfigLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return new io.fabric8.openshift.api.model.ConnectionConfigFluentImpl.TlsClientConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ConnectionConfigFluent.TlsClientConfigNested<A> editTlsClientConfig() {
    return withNewTlsClientConfigLike(getTlsClientConfig());
  }
  public io.fabric8.openshift.api.model.ConnectionConfigFluent.TlsClientConfigNested<A> editOrNewTlsClientConfig() {
    return withNewTlsClientConfigLike(getTlsClientConfig() != null ? getTlsClientConfig(): new io.fabric8.openshift.api.model.SecretNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.ConnectionConfigFluent.TlsClientConfigNested<A> editOrNewTlsClientConfigLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return withNewTlsClientConfigLike(getTlsClientConfig() != null ? getTlsClientConfig(): item);
  }
  public java.lang.String getUrl() {
    return this.url;
  }
  public A withUrl(java.lang.String url) {
    this.url=url; return (A) this;
  }
  public java.lang.Boolean hasUrl() {
    return this.url != null;
  }
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0) {
    return (A)withUrl(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConnectionConfigFluentImpl that = (ConnectionConfigFluentImpl) o;
    if (ca != null ? !ca.equals(that.ca) :that.ca != null) return false;
    if (tlsClientConfig != null ? !tlsClientConfig.equals(that.tlsClientConfig) :that.tlsClientConfig != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ca,  tlsClientConfig,  url,  additionalProperties,  super.hashCode());
  }
  public class CaNestedImpl<N> extends io.fabric8.openshift.api.model.ConfigMapNameReferenceFluentImpl<io.fabric8.openshift.api.model.ConnectionConfigFluent.CaNested<N>> implements io.fabric8.openshift.api.model.ConnectionConfigFluent.CaNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CaNestedImpl(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this, item);
    }
    CaNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder builder;
    public N and() {
      return (N) ConnectionConfigFluentImpl.this.withCa(builder.build());
    }
    public N endCa() {
      return and();
    }
    
  }
  public class TlsClientConfigNestedImpl<N> extends io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl<io.fabric8.openshift.api.model.ConnectionConfigFluent.TlsClientConfigNested<N>> implements io.fabric8.openshift.api.model.ConnectionConfigFluent.TlsClientConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TlsClientConfigNestedImpl(io.fabric8.openshift.api.model.SecretNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this, item);
    }
    TlsClientConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.SecretNameReferenceBuilder builder;
    public N and() {
      return (N) ConnectionConfigFluentImpl.this.withTlsClientConfig(builder.build());
    }
    public N endTlsClientConfig() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/ConnectionConfigFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ConnectionConfigFluentImpl<A extends io.fabric8.openshift.api.model.ConnectionConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ConnectionConfigFluent<A>{
  public ConnectionConfigFluentImpl() {
  }
  public ConnectionConfigFluentImpl(io.fabric8.openshift.api.model.ConnectionConfig instance) {
    this.withCa(instance.getCa()); 
    this.withTlsClientConfig(instance.getTlsClientConfig()); 
    this.withUrl(instance.getUrl()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder ca;
  private io.fabric8.openshift.api.model.SecretNameReferenceBuilder tlsClientConfig;
  private java.lang.String url;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildCa instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConfigMapNameReference getCa() {
    return this.ca!=null?this.ca.build():null;
  }
  public io.fabric8.openshift.api.model.ConfigMapNameReference buildCa() {
    return this.ca!=null?this.ca.build():null;
  }
  public A withCa(io.fabric8.openshift.api.model.ConfigMapNameReference ca) {
    _visitables.get("ca").remove(this.ca);
    if (ca!=null){ this.ca= new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(ca); _visitables.get("ca").add(this.ca);} return (A) this;
  }
  public java.lang.Boolean hasCa() {
    return this.ca != null;
  }
  public A withNewCa(java.lang.String name) {
    return (A)withCa(new ConfigMapNameReference(name));
  }
  public io.fabric8.openshift.api.model.ConnectionConfigFluent.CaNested<A> withNewCa() {
    return new io.fabric8.openshift.api.model.ConnectionConfigFluentImpl.CaNestedImpl();
  }
  public io.fabric8.openshift.api.model.ConnectionConfigFluent.CaNested<A> withNewCaLike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
    return new io.fabric8.openshift.api.model.ConnectionConfigFluentImpl.CaNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ConnectionConfigFluent.CaNested<A> editCa() {
    return withNewCaLike(getCa());
  }
  public io.fabric8.openshift.api.model.ConnectionConfigFluent.CaNested<A> editOrNewCa() {
    return withNewCaLike(getCa() != null ? getCa(): new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.ConnectionConfigFluent.CaNested<A> editOrNewCaLike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
    return withNewCaLike(getCa() != null ? getCa(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildTlsClientConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getTlsClientConfig() {
    return this.tlsClientConfig!=null?this.tlsClientConfig.build():null;
  }
  public io.fabric8.openshift.api.model.SecretNameReference buildTlsClientConfig() {
    return this.tlsClientConfig!=null?this.tlsClientConfig.build():null;
  }
  public A withTlsClientConfig(io.fabric8.openshift.api.model.SecretNameReference tlsClientConfig) {
    _visitables.get("tlsClientConfig").remove(this.tlsClientConfig);
    if (tlsClientConfig!=null){ this.tlsClientConfig= new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(tlsClientConfig); _visitables.get("tlsClientConfig").add(this.tlsClientConfig);} return (A) this;
  }
  public java.lang.Boolean hasTlsClientConfig() {
    return this.tlsClientConfig != null;
  }
  public A withNewTlsClientConfig(java.lang.String name) {
    return (A)withTlsClientConfig(new SecretNameReference(name));
  }
  public io.fabric8.openshift.api.model.ConnectionConfigFluent.TlsClientConfigNested<A> withNewTlsClientConfig() {
    return new io.fabric8.openshift.api.model.ConnectionConfigFluentImpl.TlsClientConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.ConnectionConfigFluent.TlsClientConfigNested<A> withNewTlsClientConfigLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return new io.fabric8.openshift.api.model.ConnectionConfigFluentImpl.TlsClientConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ConnectionConfigFluent.TlsClientConfigNested<A> editTlsClientConfig() {
    return withNewTlsClientConfigLike(getTlsClientConfig());
  }
  public io.fabric8.openshift.api.model.ConnectionConfigFluent.TlsClientConfigNested<A> editOrNewTlsClientConfig() {
    return withNewTlsClientConfigLike(getTlsClientConfig() != null ? getTlsClientConfig(): new io.fabric8.openshift.api.model.SecretNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.ConnectionConfigFluent.TlsClientConfigNested<A> editOrNewTlsClientConfigLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return withNewTlsClientConfigLike(getTlsClientConfig() != null ? getTlsClientConfig(): item);
  }
  public java.lang.String getUrl() {
    return this.url;
  }
  public A withUrl(java.lang.String url) {
    this.url=url; return (A) this;
  }
  public java.lang.Boolean hasUrl() {
    return this.url != null;
  }
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0) {
    return (A)withUrl(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConnectionConfigFluentImpl that = (ConnectionConfigFluentImpl) o;
    if (ca != null ? !ca.equals(that.ca) :that.ca != null) return false;
    if (tlsClientConfig != null ? !tlsClientConfig.equals(that.tlsClientConfig) :that.tlsClientConfig != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ca,  tlsClientConfig,  url,  additionalProperties,  super.hashCode());
  }
  public class CaNestedImpl<N> extends io.fabric8.openshift.api.model.ConfigMapNameReferenceFluentImpl<io.fabric8.openshift.api.model.ConnectionConfigFluent.CaNested<N>> implements io.fabric8.openshift.api.model.ConnectionConfigFluent.CaNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CaNestedImpl(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this, item);
    }
    CaNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder builder;
    public N and() {
      return (N) ConnectionConfigFluentImpl.this.withCa(builder.build());
    }
    public N endCa() {
      return and();
    }
    
  }
  public class TlsClientConfigNestedImpl<N> extends io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl<io.fabric8.openshift.api.model.ConnectionConfigFluent.TlsClientConfigNested<N>> implements io.fabric8.openshift.api.model.ConnectionConfigFluent.TlsClientConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TlsClientConfigNestedImpl(io.fabric8.openshift.api.model.SecretNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this, item);
    }
    TlsClientConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.SecretNameReferenceBuilder builder;
    public N and() {
      return (N) ConnectionConfigFluentImpl.this.withTlsClientConfig(builder.build());
    }
    public N endTlsClientConfig() {
      return and();
    }
    
  }
  
}
